##Project
This project contains a nova backend that can be used to train models or generate explanations for the models on a remote server.
The server api can be used either from the UI itself or as a standalone tool to just interact with an existing nova database.

##Usage
The recommended way of usage is to install the latest stable version of the package via pypi from [here](https://pypi.org/project/hcai-nova-server/).

Alternatively you can use the nightly version of the current github dev-commit from [here](https://pypi.org/project/hcai-nova-server-nightly/).

Once installed you can then start the server using the command line as such:

```  ```
